%==========================================================================
% Figure 5 / Numerical example
% see optimum.m for details
%==========================================================================

param(1)=0.0001;   %pi;
param(2)=0.01;     %p1;
param(3)=0.25;     %ci;
param(4)=20;        %cnc;
param(5)=100;      %ca;
param(6)=2;        %cs_nc;
param(7)=2.5;      %cs_c;
param(8)=0.01;     %alpha;
param(9)=0.01;     %beta;
param(10)=1e-6;    %deltamax;
param(11)=0.03;    %phimax;

% Model 1 = Exponential
vm=[1:100 200:100:1000 2000:2000:10000 20000:20000:100000 200000:200000:1000000];
nm=length(vm);
results=zeros(nm,4);

for i=1:nm
    m=vm(i);
    [mo,ro,Co,phio,chainlog,output]=optimum(param,[m m],[],[0 0 0],1,i);
    results(i,1)=output(1,1);  %m
    results(i,2)=output(1,2);  %C
    results(i,3)=output(1,3);  %r
    results(i,4)=output(1,4);  %phi
    results(i,5)=output(1,5);  %n
end

% Getting optimum point
[mo,ro,Co,phio,chainlog,output]=optimum(param,[],[],[0 0 1],1,i);
no=chainlog(length(chainlog),1);

% Plotting
tfonte=7;
nfonte='Times';

figure;
set(gcf,'Color',[1,1,1]);

subplot(2,2,1);
plot(results(:,1),results(:,2),'k-');
hold on;
plot(mo,Co,'ro','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',3);
xlabel('m','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
ylabel('C','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
title('(a)','FontSize',tfonte,'FontName','Times');
set(gca,'XScale','log')
set(gca,'YScale','log')

minimumy=10^floor(log10(min(results(:,2))));
maximumy=param(4);

ylim([minimumy maximumy]);
set(gca,'FontSize',tfonte,'FontName','Times')
set(gca,'YTick',[minimumy 1 10 20]);


subplot(2,2,2);
plot(results(:,1),results(:,5),'k-');
hold on;
plot(mo,no,'ro','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',3);
xlabel('m','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
ylabel('n','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
title('(b)','FontSize',tfonte,'FontName','Times');
set(gca,'XScale','log')
%set(gca,'YScale','log')

ylim([2 30]);
set(gca,'FontSize',tfonte,'FontName','Times')
%set(gca,'YTick',[2 10 20 30]);

subplot(2,2,3);
plot(results(:,1),results(:,3),'k-');
hold on;
plot(mo,ro,'ro','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',3);
xlabel('m','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
ylabel('r','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
title('(c)','FontSize',tfonte,'FontName','Times');
set(gca,'XScale','log')
set(gca,'FontSize',tfonte,'FontName','Times')

subplot(2,2,4);
plot(results(:,1),results(:,4),'k-');
hold on;
plot(mo,phio,'ro','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',3);
xlabel('m','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
ylabel('\phi','FontSize',tfonte+1,'FontName','Times','FontAngle','italic');
title('(d)','FontSize',tfonte,'FontName','Times');
set(gca,'XScale','log')
set(gca,'FontSize',tfonte,'FontName','Times')

drawnow;
set(gcf,'PaperPositionMode','auto');
print('-dpdf','-r120','figure5.pdf');
close(gcf);

