%==========================================================================
% Figure 6 / Numerical example
% see optimum.m for details
%==========================================================================

param(1)=0.0001;   %pi;
param(2)=0.01;     %p1;
param(3)=0.25;     %ci;
param(4)=20;       %cnc;
param(5)=100;      %ca;
param(6)=2;        %cs_nc;
param(7)=2.5;      %cs_c;
param(8)=0.01;     %alpha;
param(9)=0.01;     %beta;
param(10)=1e-6;    %deltamax;
param(11)=0.03;    %phimax;


valpha=linspace(0.0,0.2,9);
vbeta=valpha;

nalpha=length(valpha);
nbeta=length(vbeta);

ALPHA=zeros(nalpha,nbeta);
BETA=zeros(nalpha,nbeta);
M=zeros(nalpha,nbeta);
R=zeros(nalpha,nbeta);

cont=0;
	
for i=1:nalpha

    for j=1:nbeta

		cont=cont+1;
		
        param(8)=valpha(i);     %alpha;
        param(9)=vbeta(j);      %beta;

        [mo,ro,Co,phio]=optimum(param,[],[],[0 1 1],1,cont);

        ALPHA(i,j)=param(8);
        BETA(i,j)=param(9);

        M(i,j)=mo;
        R(i,j)=ro;

    end
    
end


figure;
set(gcf,'Color',[1,1,1]);

tfonte=7;
nfonte='Times';

subplot(2,2,1);
mesh(ALPHA,BETA,M,'FaceColor',[1 1 1],'Marker','.','MarkerSize',10,'EdgeColor','black');
xlim([min(valpha) max(valpha)]);
ylim([min(vbeta) max(vbeta)]);

set(gca,'XTick',[0.0 0.1 0.2]);
set(gca,'XTickLabel',{'0%','10%','20%'});
set(gca,'YTick',[0.0 0.1 0.2]);
set(gca,'YTickLabel',{'0%','10%','20%'});

xlabel('\alpha','FontSize',tfonte,'FontName','Times','FontAngle','italic');
ylabel('\beta','FontSize',tfonte,'FontName','Times','FontAngle','italic');
zlabel('m\circ','FontSize',tfonte,'FontName','Times','FontAngle','italic');
set(gca,'FontSize',tfonte,'FontName','Times');
set(gca,'GridLineStyle','-')


subplot(2,2,2);
mesh(ALPHA,BETA,R,'FaceColor',[1 1 1],'Marker','.','MarkerSize',10,'EdgeColor','black');
xlim([min(valpha) max(valpha)]);
ylim([min(vbeta) max(vbeta)]);
zlim([0 max(max(R))+1]);

set(gca,'XTick',[0.0 0.1 0.2]);
set(gca,'XTickLabel',{'0%','10%','20%'});
set(gca,'YTick',[0.0 0.1 0.2]);
set(gca,'YTickLabel',{'0%','10%','20%'});
set(gca,'ZTick',[0 4 8 12]);

xlabel('\alpha','FontSize',tfonte,'FontName','Times','FontAngle','italic');
ylabel('\beta','FontSize',tfonte,'FontName','Times','FontAngle','italic');
zlabel('r\circ','FontSize',tfonte,'FontName','Times','FontAngle','italic');
set(gca,'FontSize',tfonte,'FontName','Times');
set(gca,'GridLineStyle','-')

drawnow;
set(gcf,'PaperPositionMode','auto');
print('-dpdf','-r120','figure6.pdf');



